// Pseudo-character tokens outside ASCII range. The curses wgetch() function
// will return any given one of these only if the corresponding k- capability
// is defined in your terminal's terminfo entry.
const
 KEY_CODE_YES	= &0400;	// A wchar_t contains a key code
 KEY_MIN	= &0401;	// Minimum curses key
 KEY_BREAK	= &0401;	// Break key (unreliable)
 KEY_DOWN	= &0402;	// Down-arrow
 KEY_UP		= &0403;	// Up-arrow
 KEY_LEFT	= &0404;	// Left-arrow
 KEY_RIGHT	= &0405;	// Right-arrow
 KEY_HOME	= &0406;	// Home key (upward+left arrow)
 KEY_BACKSPACE	= &0407;	// Backspace (unreliable)
 KEY_F0		= &0410;	// Function keys. Space for 64
 KEY_F1		= &0411;
 KEY_F2		= &0412;
 KEY_F3		= &0413;
 KEY_F4		= &0414;
 KEY_F5		= &0415;
 KEY_F6		= &0416;
 KEY_F7		= &0417;
 KEY_F8		= &0420;
 KEY_F9		= &0421;
 KEY_F10	= &0422;
 KEY_F11	= &0423;
 KEY_F12	= &0424;
 KEY_F13	= &0425;
 KEY_F14	= &0426;
 KEY_F15	= &0427;
 KEY_F16	= &0430;
 KEY_F17	= &0431;
 KEY_F18	= &0432;
 KEY_F19	= &0433;
 KEY_F20	= &0434;
 KEY_F21	= &0435;
 KEY_F22	= &0436;
 KEY_F23	= &0437;
 KEY_F24	= &0440;
 KEY_DL		= &0510;	// Delete line
 KEY_IL		= &0511;	// Insert line
 KEY_DC		= &0512;	// Delete character
 KEY_IC		= &0513;	// Insert char or enter insert mode
 KEY_EIC	= &0514;	// Exit insert char mode
 KEY_CLEAR	= &0515;	// Clear screen
 KEY_EOS	= &0516;	// Clear to end of screen
 KEY_EOL	= &0517;	// Clear to end of line
 KEY_SF		= &0520;	// Scroll 1 line forward
 KEY_SR		= &0521;	// Scroll 1 line backward (reverse)
 KEY_NPAGE	= &0522;	// Next page
 KEY_PPAGE	= &0523;	// Previous page
 KEY_STAB	= &0524;	// Set tab
 KEY_CTAB	= &0525;	// Clear tab
 KEY_CATAB	= &0526;	// Clear all tabs
 KEY_ENTER	= &0527;	// Enter or send (unreliable)
 KEY_SRESET	= &0530;	// Soft (partial) reset (unreliable)
 KEY_RESET	= &0531;	// Reset or hard reset (unreliable)
 KEY_PRINT	= &0532;	// Print
 KEY_LL		= &0533;	// Home down or bottom (lower left)

// The keypad is arranged like this: 
// a1   up  a3 
// left b2 right 
// c1  down c3 

 KEY_A1		= &0534;	// Upper left of keypad
 KEY_A3		= &0535;	// Upper right of keypad
 KEY_B2		= &0536;	// Center of keypad
 KEY_C1		= &0537;	// Lower left of keypad
 KEY_C3		= &0540;	// Lower right of keypad
 KEY_BTAB	= &0541;	// Back tab
 KEY_BEG	= &0542;	// Beg (beginning)
 KEY_CANCEL	= &0543;	// Cancel
 KEY_CLOSE	= &0544;	// Close
 KEY_COMMAND	= &0545;	// Cmd (command)
 KEY_COPY	= &0546;	// Copy
 KEY_CREATE	= &0547;	// Create
 KEY_END	= &0550;	// End
 KEY_EXIT	= &0551;	// Exit
 KEY_FIND	= &0552;	// Find
 KEY_HELP	= &0553;	// Help
 KEY_MARK	= &0554;	// Mark
 KEY_MESSAGE	= &0555;	// Message
 KEY_MOVE	= &0556;	// Move
 KEY_NEXT	= &0557;	// Next
 KEY_OPEN	= &0560;	// Open
 KEY_OPTIONS	= &0561;	// Options
 KEY_PREVIOUS	= &0562;	// Prev (previous)
 KEY_REDO	= &0563;	// Redo
 KEY_REFERENCE	= &0564;	// Ref (reference)
 KEY_REFRESH	= &0565;	// Refresh
 KEY_REPLACE	= &0566;	// Replace
 KEY_RESTART	= &0567;	// Restart
 KEY_RESUME	= &0570;	// Resume
 KEY_SAVE	= &0571;	// Save
 KEY_SBEG	= &0572;	// Shifted Beg (beginning)
 KEY_SCANCEL	= &0573;	// Shifted Cancel
 KEY_SCOMMAND	= &0574;	// Shifted Command
 KEY_SCOPY	= &0575;	// Shifted Copy
 KEY_SCREATE	= &0576;	// Shifted Create
 KEY_SDC	= &0577;	// Shifted Delete char
 KEY_SDL	= &0600;	// Shifted Delete line
 KEY_SELECT	= &0601;	// Select
 KEY_SEND	= &0602;	// Shifted End
 KEY_SEOL	= &0603;	// Shifted Clear line
 KEY_SEXIT	= &0604;	// Shifted Dxit
 KEY_SFIND	= &0605;	// Shifted Find
 KEY_SHELP	= &0606;	// Shifted Help
 KEY_SHOME	= &0607;	// Shifted Home
 KEY_SIC	= &0610;	// Shifted Input
 KEY_SLEFT	= &0611;	// Shifted Left arrow
 KEY_SMESSAGE	= &0612;	// Shifted Message
 KEY_SMOVE	= &0613;	// Shifted Move
 KEY_SNEXT	= &0614;	// Shifted Next
 KEY_SOPTIONS	= &0615;	// Shifted Options
 KEY_SPREVIOUS	= &0616;	// Shifted Prev
 KEY_SPRINT	= &0617;	// Shifted Print
 KEY_SREDO	= &0620;	// Shifted Redo
 KEY_SREPLACE	= &0621;	// Shifted Replace
 KEY_SRIGHT	= &0622;	// Shifted Right arrow
 KEY_SRSUME	= &0623;	// Shifted Resume
 KEY_SSAVE	= &0624;	// Shifted Save
 KEY_SSUSPEND	= &0625;	// Shifted Suspend
 KEY_SUNDO	= &0626;	// Shifted Undo
 KEY_SUSPEND	= &0627;	// Suspend
 KEY_UNDO	= &0630;	// Undo
 KEY_MOUSE	= &0631;	// Mouse event has occurred
 KEY_RESIZE	= &0632;	// Terminal resize event
 KEY_MAX	= &0777;	// Maximum key value
